### Setup

```
pip3 install --quiet -r requirements.txt
```

To run llama and other LLMs that need an agreement (not SmolLM), you first have to type the following:
```
huggingface-cli login
```
Above will ask you for the hf_token, which is the same you use e.g. in colab
